# /* ****************************************************************** **
# **                    BraineryWiz TCL version                         **
# **              by Bijan Sayyafzadeh & Silvia Mazzoni                 **
# **                                                                    **
# **                                                                    **
# ** (C) Copyright 2022, Bijan Sayyafzadeh & Silvia Mazzoni             **
# **       SilviaBrainery.com                                           **
# ** All Rights Reserved.                                               **
# **                                                                    **
# ** Commercial use of this program without express permission of the   **
# ** https://www.silviasbrainery.com/ (BraineryWiz@Gmail.com), is       **
# ** strictly prohibited.  See file 'COPYRIGHT'  in main directory      **
# ** for information on usage and redistribution,  and for a            **
# ** DISCLAIMER OF ALL WARRANTIES.                                      **
# **                                                                    **
# ** Developed by:                                                      **
# **   Bijan SayyafZadeh (B.Sayyaf@yahoo.com)                           **
# **   SilviaMazzoni     (SilviaMazzoni@Yahoo.com)                      **
# **                                                                    **
# ** ****************************************************************** */

import sys

# only work for 64 bit system
if sys.maxsize < 2**31:
    raise RuntimeError('64 bit system is required')

# platform dependent
if sys.platform.startswith('linux'):

    try:
        # from openseespylinux.opensees import *
        raise RuntimeError(sys.platform+' is not supported yet')

    except:
        raise RuntimeError('Failed to import openseespy on Linux.')

elif sys.platform.startswith('win'):

    try:
        from .PlotModel import PlotModel
        from .PlotAnimation import RecorderReset, Record, PlotAnime, PlotAnimeGif
        from .PlotDefo import PlotDefo
        from .PlotModeShape import PlotModeShape
        from .RealTime import RealTimeObj, RealTimeUpdate
        from .FEMWiz import BaseData, DispData, EigenData

    except:
        raise RuntimeError('Use Python Version 3.11.5. If you are not using Anaconda environment instead of installing mentioned version of python you can install older version of BraineryWiz (pip install BraineryWiz==0.91) But it does not work on Anaconda environment!  For more information visit: https://silvia-s-brainery.github.io/BraineryWizDocumentation/Python_Version/installation.html')

elif sys.platform.startswith('darwin'):

    try:
        # from openseespymac.opensees import *
        raise RuntimeError(sys.platform+' is not supported yet')

    except:
        raise RuntimeError('Failed to import openseespy on Mac.')


else:

    raise RuntimeError(sys.platform+' is not supported yet')


# /* ****************************************************************** **
# **                    BraineryWiz TCL version                         **
# **              by Bijan Sayyafzadeh & Silvia Mazzoni                 **
# **                                                                    **
# **                                                                    **
# ** (C) Copyright 2022, Bijan Sayyafzadeh & Silvia Mazzoni             **
# **       SilviaBrainery.com                                           **
# ** All Rights Reserved.                                               **
# **                                                                    **
# ** Commercial use of this program without express permission of the   **
# ** https://www.silviasbrainery.com/ (BraineryWiz@Gmail.com), is       **
# ** strictly prohibited.  See file 'COPYRIGHT'  in main directory      **
# ** for information on usage and redistribution,  and for a            **
# ** DISCLAIMER OF ALL WARRANTIES.                                      **
# **                                                                    **
# ** Developed by:                                                      **
# **   Bijan SayyafZadeh (B.Sayyaf@yahoo.com)                           **
# **   SilviaMazzoni     (SilviaMazzoni@Yahoo.com)                      **
# **                                                                    **
# ** ****************************************************************** */

from setuptools import setup, find_packages

import subprocess
import os

BraineryWiz_version = (
    subprocess.run(["git", "describe", "--tags"], stdout=subprocess.PIPE)
    .stdout.decode("utf-8")
    .strip()
)

assert "." in BraineryWiz_version

assert os.path.isfile("BraineryWiz/version.py")
with open("BraineryWiz/VERSION", "w", encoding="utf-8") as fh:
    fh.write(f"{BraineryWiz_version}\n")



with open("README.md", "r") as fh:
    long_description = fh.read()


setup(
    name="BraineryWiz",
    version=BraineryWiz_version,
    author="Bijan Sayyafzadeh - Silvia Mazzoni",
    author_email="<BraineryWiz@Gmail.com>",
    description="OpenSees Plotting Package",
    long_description_content_type="text/markdown",
    long_description=long_description ,
    package_data={
        "":["*.jpg","*.at2","*.pyd"],
        # If any package contains *.txt or *.rst files, include them:
        #"": ["*.txt", "*.rst"],
        # And include any *.msg files found in the "hello" package, too:
        #"hello": ["*.msg"],
    },
    packages=find_packages(),
    install_requires=['openseespy', 'eseesminipy','numpy','plotly','scipy','pillow','kaleido','tqdm','ipywidgets'],
    url="https://github.com/Silvia-s-Brainery/BraineryWiz",
    keywords=['python', 'opensees', 'Modeling', 'Dynamic'],
    classifiers=[
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Operating System :: Microsoft :: Windows'
    ],

)
